==> mm2s5-0.1.0.tar.gz: mm2s5-0.1.0/doc/sample.mm <==
<map version="0.8.0">
<!-- To view this file, download free mind mapping software FreeMind from http://freemind.sourceforge.net -->
<node CREATED="1174751731272" ID="Freemind_Link_1375153691" MODIFIED="1174751756188" TEXT="Sample Presentation&#xa;This is a subtitle">
<node CREATED="1174751760014" FOLDED="true" ID="_" MODIFIED="1174751763182" POSITION="right" TEXT="__meta__">
<node CREATED="1174751795416" ID="Freemind_Link_853958109" MODIFIED="1174751809263" TEXT="author">
<node CREATED="1174751809725" ID="Freemind_Link_1380599025" MODIFIED="1174751812742" TEXT="Scott Kirkwood"/>
</node>
<node CREATED="1174751813861" ID="Freemind_Link_90480278" MODIFIED="1174751820213" TEXT="company">
<node CREATED="1174751820829" ID="Freemind_Link_419305574" MODIFIED="1174751824012" TEXT="Scott&apos;s Company"/>
</node>
<node CREATED="1174751824974" ID="Freemind_Link_1947628856" MODIFIED="1174751844801" TEXT="template">
<node CREATED="1174751845190" ID="Freemind_Link_1949302222" MODIFIED="1174852585418" TEXT="scott"/>
</node>
<node CREATED="1174751850611" ID="Freemind_Link_1574980523" MODIFIED="1174751852424" TEXT="presdate">
<node CREATED="1174751853167" ID="Freemind_Link_439664286" MODIFIED="1174751854488" TEXT="today"/>
</node>
</node>
<node CREATED="1174752016014" ID="Freemind_Link_159967983" MODIFIED="1174752024796" POSITION="right" TEXT="Introduction">
<node CREATED="1174752026691" ID="Freemind_Link_53747272" MODIFIED="1174832725201" TEXT="mm2s5 creates a simple presentation from a FreeMind mind map"/>
<node CREATED="1174832726006" ID="Freemind_Link_1564567694" MODIFIED="1174833191787" TEXT="Each slide page has line items">
<node CREATED="1174832744235" ID="Freemind_Link_283375268" MODIFIED="1174833198336" TEXT="That can">
<node CREATED="1174833198296" ID="Freemind_Link_395681060" MODIFIED="1174833200962" TEXT="be nested">
<node CREATED="1174832750000" ID="Freemind_Link_1613988249" MODIFIED="1174833208974" TEXT="to any">
<node CREATED="1174832756256" ID="Freemind_Link_736159912" MODIFIED="1174833214896" TEXT="depth"/>
</node>
</node>
</node>
</node>
</node>
<node CREATED="1174839871068" ID="Freemind_Link_750472158" MODIFIED="1174839955990" POSITION="right" TEXT="Tricks">
<node CREATED="1174839874532" ID="Freemind_Link_733689660" MODIFIED="1174839967523" TEXT="You can enter any &lt;strike&gt;HTML&lt;/strike&gt;tags"/>
<node CREATED="1174839906478" ID="Freemind_Link_1730451604" MODIFIED="1174839952973" TEXT="If your FreeMind node starts with a &amp;lt; it will not put it in in a list item"/>
<node CREATED="1174840017867" ID="Freemind_Link_955633750" MODIFIED="1174840051783" TEXT="If you&apos;re have a node with next &quot;__table__&quot; the child elements will be considered row and columns of a table."/>
</node>
<node CREATED="1174752056872" ID="Freemind_Link_1154474301" MODIFIED="1174847922103" POSITION="right" TEXT="Tables">
<icon BUILTIN="button_ok"/>
<node CREATED="1174834118567" ID="Freemind_Link_1614609677" MODIFIED="1174834127580" TEXT="Simple tables can be put in relatively easily"/>
<node CREATED="1174752065981" ID="Freemind_Link_1246944983" MODIFIED="1174833286011" TEXT="__table__">
<node CREATED="1174833546603" ID="Freemind_Link_1196997985" MODIFIED="1174833588084" TEXT="Based on concentrations (ppb) adjusted for heat retention characteristics">
<node CREATED="1174833596523" ID="Freemind_Link_17506322" MODIFIED="1174833602745" TEXT="Percent of Total">
<node CREATED="1174833603307" ID="Freemind_Link_1457750476" MODIFIED="1174833626157" TEXT="Percent of total - ajusted for water vapor"/>
</node>
</node>
<node CREATED="1174833637357" ID="Freemind_Link_526339615" MODIFIED="1174833707408" TEXT="Water Vapor (H20)">
<node CREATED="1174833725429" ID="Freemind_Link_105457188" MODIFIED="1174833729068" TEXT="---">
<node CREATED="1174833785539" ID="Freemind_Link_35161907" MODIFIED="1174833787923" TEXT="95.000%"/>
</node>
</node>
<node CREATED="1174833640953" ID="Freemind_Link_1741096651" MODIFIED="1174833702001" TEXT="Carbon Dioxide (CO2)">
<node CREATED="1174833802105" ID="Freemind_Link_1085073204" MODIFIED="1174833803984" TEXT="72.369%">
<node CREATED="1174833804624" ID="Freemind_Link_1838555189" MODIFIED="1174833815542" TEXT="3.618%"/>
</node>
</node>
<node CREATED="1174833649281" ID="Freemind_Link_39729027" MODIFIED="1174833692874" TEXT="Methane (CH4)">
<node CREATED="1174833818145" ID="Freemind_Link_1622539256" MODIFIED="1174833825869" TEXT="7.100%">
<node CREATED="1174833835374" ID="Freemind_Link_353881474" MODIFIED="1174833837515" TEXT="0.360%"/>
</node>
</node>
<node CREATED="1174833672497" ID="Freemind_Link_1198159536" MODIFIED="1174833672497" TEXT="Nitrous oxide (N2O)">
<node CREATED="1174833846122" ID="Freemind_Link_1435923942" MODIFIED="1174833849868" TEXT="19.000%">
<node CREATED="1174833856415" ID="Freemind_Link_1657014193" MODIFIED="1174833858440" TEXT="0.950%"/>
</node>
</node>
<node CREATED="1174833713476" ID="Freemind_Link_849268394" MODIFIED="1174833721542" TEXT="CFC + Other gases">
<node CREATED="1174833860623" ID="Freemind_Link_477528685" MODIFIED="1174833867214" TEXT="1.432%">
<node CREATED="1174833868751" ID="Freemind_Link_1760366784" MODIFIED="1174833878284" TEXT="0.072%"/>
</node>
</node>
<node CREATED="1174833722109" ID="Freemind_Link_1635364715" MODIFIED="1174834085931" TEXT="&lt;b&gt;Total&lt;/b&gt;">
<node CREATED="1174833880180" ID="Freemind_Link_833280758" MODIFIED="1174834078996" TEXT="&lt;b&gt;100%&lt;/b&gt;">
<node CREATED="1174833883700" ID="Freemind_Link_22839263" MODIFIED="1174834069573" TEXT="&lt;b&gt;100%&lt;/b&gt;"/>
</node>
</node>
</node>
<node CREATED="1174834305480" ID="Freemind_Link_1078564850" MODIFIED="1174834400909" TEXT="Borrowed from &lt;a href=&quot;http://www.geocraft.com/WVFossils/greenhouse_data.html&quot;&gt;Geocraft site&lt;/a&gt;"/>
</node>
<node CREATED="1174841038118" ID="Freemind_Link_1256880767" MODIFIED="1174841516067" POSITION="right" TEXT="Ordered List">
<icon BUILTIN="full-1"/>
<node CREATED="1174841526909" ID="Freemind_Link_35317442" MODIFIED="1174847971908" TEXT="Put purple 1 icon on the parent node"/>
<node CREATED="1174841546818" ID="Freemind_Link_1489257514" MODIFIED="1174847973804" TEXT="and"/>
<node CREATED="1174841549130" ID="Freemind_Link_1208377627" MODIFIED="1174847984914" TEXT="the items"/>
<node CREATED="1174841556650" ID="Freemind_Link_434665712" MODIFIED="1174847982843" TEXT="will be"/>
<node CREATED="1174841558186" ID="Freemind_Link_299177855" MODIFIED="1174841559626" TEXT="numbered"/>
<node CREATED="1174848538432" ID="Freemind_Link_1047194298" MODIFIED="1174848543910" TEXT="&lt;html&gt;&lt;img src=&quot;ordered-list.png&quot;&gt;"/>
</node>
<node CREATED="1174841149071" ID="Freemind_Link_623004043" MODIFIED="1174841425279" POSITION="right" TEXT="No list">
<icon BUILTIN="button_ok"/>
<node CREATED="1174841170600" ID="Freemind_Link_1198817827" MODIFIED="1174841433998" TEXT="Put a green check on the slide"/>
<node CREATED="1174841176281" ID="Freemind_Link_1388657062" MODIFIED="1174847645633" TEXT="And the items below won&apos;t"/>
<node CREATED="1174841270465" ID="Freemind_Link_1149087460" MODIFIED="1174841440893" TEXT="appears as a list">
<node CREATED="1174847647479" ID="Freemind_Link_846236540" MODIFIED="1174847656583" TEXT="But sub-sub items"/>
<node CREATED="1174847657288" ID="Freemind_Link_1959688204" MODIFIED="1174847663118" TEXT="still will"/>
</node>
<node CREATED="1174848547769" ID="Freemind_Link_573941588" MODIFIED="1174848553470" TEXT="&lt;html&gt;&lt;img src=&quot;no-list.png&quot;&gt;"/>
</node>
<node CREATED="1174841570127" ID="Freemind_Link_705431280" MODIFIED="1174848504676" POSITION="right" TEXT="Stop Light">
<font NAME="SansSerif" SIZE="12"/>
<icon BUILTIN="stop"/>
<node CREATED="1174841579663" ID="Freemind_Link_851925350" MODIFIED="1174841587693" TEXT="The stoplight icon"/>
<node CREATED="1174841588120" ID="Freemind_Link_735027721" MODIFIED="1174841592229" TEXT="Will make your"/>
<node CREATED="1174841592912" ID="Freemind_Link_1280768916" MODIFIED="1174841596523" TEXT="Slide build one"/>
<node CREATED="1174841597052" ID="Freemind_Link_1582095053" MODIFIED="1174841599659" TEXT="row at a"/>
<node CREATED="1174841599972" ID="Freemind_Link_1826299810" MODIFIED="1174841602163" TEXT="time"/>
<node CREATED="1174848756502" ID="Freemind_Link_1723383289" MODIFIED="1174848772902" TEXT="&lt;html&gt;&lt;img src=&quot;slide-build.png&quot;&gt;"/>
</node>
<node CREATED="1174841275781" ID="Freemind_Link_341540712" MODIFIED="1174841448838" POSITION="right" TEXT="Skip everything">
<icon BUILTIN="button_cancel"/>
<node CREATED="1174841283118" ID="Freemind_Link_656473777" MODIFIED="1174841462467" TEXT="Put a red X"/>
<node CREATED="1174841463266" ID="Freemind_Link_252156480" MODIFIED="1174841468552" TEXT="And the slide is disabled"/>
</node>
<node CREATED="1174848435964" ID="Freemind_Link_545870954" MODIFIED="1174848450137" POSITION="right" TEXT="Skip a slide">
<icon BUILTIN="button_ok"/>
<node CREATED="1174848452752" ID="Freemind_Link_692571033" MODIFIED="1174848514621" TEXT="You can skip a slide like the previous one, which you didn&apos;t see."/>
<node CREATED="1174848519980" ID="Freemind_Link_1102571794" MODIFIED="1174848530343" TEXT="&lt;html&gt;&lt;img src=&quot;skip-everything.png&quot;&gt;"/>
</node>
<node CREATED="1174752104422" ID="Freemind_Link_846585405" MODIFIED="1174847601163" POSITION="right" TEXT="Pros">
<icon BUILTIN="button_ok"/>
<node CREATED="1174839324379" ID="Freemind_Link_1022412731" MODIFIED="1174847597779" TEXT="Advantages of mm2s5">
<node CREATED="1174839332711" ID="Freemind_Link_717364200" MODIFIED="1174839345232" TEXT="Very quick and easy"/>
<node CREATED="1174839345760" ID="Freemind_Link_1978241350" MODIFIED="1174839363717" TEXT="FreeMind has a great GUI and is very intuitive to use"/>
<node CREATED="1174839364701" ID="Freemind_Link_1996043803" MODIFIED="1174839375267" TEXT="FreeMind and S5 are actively supported"/>
<node CREATED="1174839375805" ID="Freemind_Link_803895694" MODIFIED="1174839711508" TEXT="FreeMinds, S5 and mm2s5 are all cross platform"/>
<node CREATED="1174839720517" ID="Freemind_Link_1436744254" MODIFIED="1174839733297" TEXT="FreeMind is useful for more than just presentations :-)"/>
<node CREATED="1174839670187" ID="Freemind_Link_701917635" MODIFIED="1174839684137" TEXT="You can create nice presentations templates in CSS"/>
</node>
</node>
<node CREATED="1174839411719" ID="Freemind_Link_1493526131" MODIFIED="1174847896443" POSITION="right" TEXT="Cons">
<icon BUILTIN="button_ok"/>
<node CREATED="1174839413823" ID="Freemind_Link_1517639954" MODIFIED="1174839420364" TEXT="Problems with mm2s5">
<node CREATED="1174839421091" ID="Freemind_Link_1092961195" MODIFIED="1174839437378" TEXT="Need to edit/compile/test your presentations"/>
<node CREATED="1174839438256" ID="Freemind_Link_1702747986" MODIFIED="1174839462229" TEXT="You need to remember to save in FreeMind"/>
<node CREATED="1174839462861" ID="Freemind_Link_1660574451" MODIFIED="1174839491256" TEXT="Everytime you refresh your presentation in the browser, you start on page 1"/>
<node CREATED="1174839492351" ID="Freemind_Link_794802210" MODIFIED="1174839511269" TEXT="No support for notes in the new S5 version">
<node CREATED="1174839511652" ID="Freemind_Link_1023589920" MODIFIED="1174839520732" TEXT="Hey, but that&apos;s where you can help!"/>
</node>
</node>
</node>
<node CREATED="1174839582375" ID="Freemind_Link_454371010" MODIFIED="1174839586697" POSITION="right" TEXT="Conclusions">
<node CREATED="1174839587271" ID="Freemind_Link_1043861456" MODIFIED="1174839607333" TEXT="If you stick to a simple presentations you can create something very quickly and easily"/>
<node CREATED="1174839607804" ID="Freemind_Link_1202228416" MODIFIED="1174839627642" TEXT="S5 is cross platform and you can show it anywhere"/>
<node CREATED="1174839639074" ID="Freemind_Link_1010048099" MODIFIED="1174839661292" TEXT="For longer presentations, you may find the edit/compile/test process tedious"/>
</node>
<node CREATED="1174752134072" ID="Freemind_Link_849227098" MODIFIED="1174838973294" POSITION="right" TEXT="Links">
<node CREATED="1174752136752" ID="Freemind_Link_706815722" MODIFIED="1174839811572" TEXT=" &lt;a href=&quot;http://freemind.sourceforge.net/wiki/index.php/Main_Page&quot;&gt;FreeMind&lt;/a&gt;"/>
<node CREATED="1174838973268" ID="Freemind_Link_539202117" MODIFIED="1174838977963" TEXT="S5">
<node CREATED="1174752143608" ID="Freemind_Link_1309153264" MODIFIED="1174838960582" TEXT="mm2s5 is known to work with&lt;a href=&quot;http://meyerweb.com/eric/tools/s5/&quot;&gt;S5 v1.1&lt;/a&gt;"/>
<node CREATED="1174838981291" ID="Freemind_Link_108227082" MODIFIED="1174839022692" TEXT="untested with the newer &lt;a href=&quot;http://s5project.org/&quot;&gt;S5 Project&lt;/a&gt;"/>
</node>
<node CREATED="1174752146196" ID="Freemind_Link_1896164373" MODIFIED="1174839817016" TEXT=" &lt;a href=&quot;http://code.google.com/p/mm2s5/&quot;&gt;mm2s5&lt;/a&gt;"/>
</node>
</node>
</map>

==> mm2s5-0.2.0.tar.gz: mm2s5-0.2.0/doc/sample.mm <==
<map version="0.9.0_Beta_8">
<!-- To view this file, download free mind mapping software FreeMind from http://freemind.sourceforge.net -->
<node CREATED="1174751731272" ID="Freemind_Link_1375153691" MODIFIED="1174751756188" TEXT="Sample Presentation&#xa;This is a subtitle">
<node CREATED="1174751760014" FOLDED="true" ID="_" MODIFIED="1174751763182" POSITION="right" TEXT="__meta__">
<node CREATED="1174751795416" ID="Freemind_Link_853958109" MODIFIED="1174751809263" TEXT="author">
<node CREATED="1174751809725" ID="Freemind_Link_1380599025" MODIFIED="1174751812742" TEXT="Scott Kirkwood"/>
</node>
<node CREATED="1174751813861" ID="Freemind_Link_90480278" MODIFIED="1174751820213" TEXT="company">
<node CREATED="1174751820829" ID="Freemind_Link_419305574" MODIFIED="1174751824012" TEXT="Scott&apos;s Company"/>
</node>
<node CREATED="1174751824974" ID="Freemind_Link_1947628856" MODIFIED="1174751844801" TEXT="template">
<node CREATED="1174751845190" ID="Freemind_Link_1949302222" MODIFIED="1174852585418" TEXT="scott"/>
</node>
<node CREATED="1174751850611" ID="Freemind_Link_1574980523" MODIFIED="1174751852424" TEXT="presdate">
<node CREATED="1174751853167" ID="Freemind_Link_439664286" MODIFIED="1174751854488" TEXT="today"/>
</node>
</node>
<node CREATED="1174752016014" ID="Freemind_Link_159967983" MODIFIED="1174752024796" POSITION="right" TEXT="Introduction">
<node CREATED="1174752026691" ID="Freemind_Link_53747272" MODIFIED="1174832725201" TEXT="mm2s5 creates a simple presentation from a FreeMind mind map"/>
<node CREATED="1174832726006" ID="Freemind_Link_1564567694" MODIFIED="1174833191787" TEXT="Each slide page has line items">
<node CREATED="1174832744235" ID="Freemind_Link_283375268" MODIFIED="1174833198336" TEXT="That can">
<node CREATED="1174833198296" ID="Freemind_Link_395681060" MODIFIED="1174833200962" TEXT="be nested">
<node CREATED="1174832750000" ID="Freemind_Link_1613988249" MODIFIED="1174833208974" TEXT="to any">
<node CREATED="1174832756256" ID="Freemind_Link_736159912" MODIFIED="1174833214896" TEXT="depth"/>
</node>
</node>
</node>
</node>
</node>
<node CREATED="1174839871068" ID="Freemind_Link_750472158" MODIFIED="1174839955990" POSITION="right" TEXT="Tricks">
<node CREATED="1174839874532" ID="Freemind_Link_733689660" MODIFIED="1174839967523" TEXT="You can enter any &lt;strike&gt;HTML&lt;/strike&gt;tags"/>
<node CREATED="1174839906478" ID="Freemind_Link_1730451604" MODIFIED="1174839952973" TEXT="If your FreeMind node starts with a &amp;lt; it will not put it in in a list item"/>
<node CREATED="1174840017867" ID="Freemind_Link_955633750" MODIFIED="1174840051783" TEXT="If you&apos;re have a node with next &quot;__table__&quot; the child elements will be considered row and columns of a table."/>
</node>
<node CREATED="1174752056872" ID="Freemind_Link_1154474301" MODIFIED="1174847922103" POSITION="right" TEXT="Tables">
<icon BUILTIN="button_ok"/>
<node CREATED="1174834118567" ID="Freemind_Link_1614609677" MODIFIED="1174834127580" TEXT="Simple tables can be put in relatively easily"/>
<node CREATED="1174752065981" ID="Freemind_Link_1246944983" MODIFIED="1174833286011" TEXT="__table__">
<node CREATED="1174833546603" ID="Freemind_Link_1196997985" MODIFIED="1174833588084" TEXT="Based on concentrations (ppb) adjusted for heat retention characteristics">
<node CREATED="1174833596523" ID="Freemind_Link_17506322" MODIFIED="1174833602745" TEXT="Percent of Total">
<node CREATED="1174833603307" ID="Freemind_Link_1457750476" MODIFIED="1174833626157" TEXT="Percent of total - ajusted for water vapor"/>
</node>
</node>
<node CREATED="1174833637357" ID="Freemind_Link_526339615" MODIFIED="1174833707408" TEXT="Water Vapor (H20)">
<node CREATED="1174833725429" ID="Freemind_Link_105457188" MODIFIED="1174833729068" TEXT="---">
<node CREATED="1174833785539" ID="Freemind_Link_35161907" MODIFIED="1174833787923" TEXT="95.000%"/>
</node>
</node>
<node CREATED="1174833640953" ID="Freemind_Link_1741096651" MODIFIED="1174833702001" TEXT="Carbon Dioxide (CO2)">
<node CREATED="1174833802105" ID="Freemind_Link_1085073204" MODIFIED="1174833803984" TEXT="72.369%">
<node CREATED="1174833804624" ID="Freemind_Link_1838555189" MODIFIED="1174833815542" TEXT="3.618%"/>
</node>
</node>
<node CREATED="1174833649281" ID="Freemind_Link_39729027" MODIFIED="1174833692874" TEXT="Methane (CH4)">
<node CREATED="1174833818145" ID="Freemind_Link_1622539256" MODIFIED="1174833825869" TEXT="7.100%">
<node CREATED="1174833835374" ID="Freemind_Link_353881474" MODIFIED="1174833837515" TEXT="0.360%"/>
</node>
</node>
<node CREATED="1174833672497" ID="Freemind_Link_1198159536" MODIFIED="1174833672497" TEXT="Nitrous oxide (N2O)">
<node CREATED="1174833846122" ID="Freemind_Link_1435923942" MODIFIED="1174833849868" TEXT="19.000%">
<node CREATED="1174833856415" ID="Freemind_Link_1657014193" MODIFIED="1174833858440" TEXT="0.950%"/>
</node>
</node>
<node CREATED="1174833713476" ID="Freemind_Link_849268394" MODIFIED="1174833721542" TEXT="CFC + Other gases">
<node CREATED="1174833860623" ID="Freemind_Link_477528685" MODIFIED="1174833867214" TEXT="1.432%">
<node CREATED="1174833868751" ID="Freemind_Link_1760366784" MODIFIED="1174833878284" TEXT="0.072%"/>
</node>
</node>
<node CREATED="1174833722109" ID="Freemind_Link_1635364715" MODIFIED="1174834085931" TEXT="&lt;b&gt;Total&lt;/b&gt;">
<node CREATED="1174833880180" ID="Freemind_Link_833280758" MODIFIED="1174834078996" TEXT="&lt;b&gt;100%&lt;/b&gt;">
<node CREATED="1174833883700" ID="Freemind_Link_22839263" MODIFIED="1174834069573" TEXT="&lt;b&gt;100%&lt;/b&gt;"/>
</node>
</node>
</node>
<node CREATED="1174834305480" ID="Freemind_Link_1078564850" MODIFIED="1174834400909" TEXT="Borrowed from &lt;a href=&quot;http://www.geocraft.com/WVFossils/greenhouse_data.html&quot;&gt;Geocraft site&lt;/a&gt;"/>
</node>
<node CREATED="1174841038118" ID="Freemind_Link_1256880767" MODIFIED="1174841516067" POSITION="right" TEXT="Ordered List">
<icon BUILTIN="full-1"/>
<node CREATED="1174841526909" ID="Freemind_Link_35317442" MODIFIED="1174847971908" TEXT="Put purple 1 icon on the parent node"/>
<node CREATED="1174841546818" ID="Freemind_Link_1489257514" MODIFIED="1174847973804" TEXT="and"/>
<node CREATED="1174841549130" ID="Freemind_Link_1208377627" MODIFIED="1174847984914" TEXT="the items"/>
<node CREATED="1174841556650" ID="Freemind_Link_434665712" MODIFIED="1174847982843" TEXT="will be"/>
<node CREATED="1174841558186" ID="Freemind_Link_299177855" MODIFIED="1174841559626" TEXT="numbered"/>
<node CREATED="1174848538432" ID="Freemind_Link_1047194298" MODIFIED="1174848543910">
<richcontent TYPE="NODE"><html>
  <head>
    
  </head>
  <body>
    <img src="ordered-list.png" />
  </body>
</html>
</richcontent>
</node>
</node>
<node CREATED="1174841149071" ID="Freemind_Link_623004043" MODIFIED="1174841425279" POSITION="right" TEXT="No list">
<icon BUILTIN="button_ok"/>
<node CREATED="1174841170600" ID="Freemind_Link_1198817827" MODIFIED="1174841433998" TEXT="Put a green check on the slide"/>
<node CREATED="1174841176281" ID="Freemind_Link_1388657062" MODIFIED="1174847645633" TEXT="And the items below won&apos;t"/>
<node CREATED="1174841270465" ID="Freemind_Link_1149087460" MODIFIED="1174841440893" TEXT="appears as a list">
<node CREATED="1174847647479" ID="Freemind_Link_846236540" MODIFIED="1174847656583" TEXT="But sub-sub items"/>
<node CREATED="1174847657288" ID="Freemind_Link_1959688204" MODIFIED="1174847663118" TEXT="still will"/>
</node>
<node CREATED="1174848547769" ID="Freemind_Link_573941588" MODIFIED="1174848553470">
<richcontent TYPE="NODE"><html>
  <head>
    
  </head>
  <body>
    <img src="no-list.png" />
  </body>
</html>
</richcontent>
</node>
</node>
<node CREATED="1174841570127" ID="Freemind_Link_705431280" MODIFIED="1174848504676" POSITION="right" TEXT="Stop Light">
<font NAME="SansSerif" SIZE="12"/>
<icon BUILTIN="stop"/>
<node CREATED="1174841579663" ID="Freemind_Link_851925350" MODIFIED="1174841587693" TEXT="The stoplight icon"/>
<node CREATED="1174841588120" ID="Freemind_Link_735027721" MODIFIED="1174841592229" TEXT="Will make your"/>
<node CREATED="1174841592912" ID="Freemind_Link_1280768916" MODIFIED="1174841596523" TEXT="Slide build one"/>
<node CREATED="1174841597052" ID="Freemind_Link_1582095053" MODIFIED="1174841599659" TEXT="row at a"/>
<node CREATED="1174841599972" ID="Freemind_Link_1826299810" MODIFIED="1174841602163" TEXT="time"/>
<node CREATED="1174848756502" ID="Freemind_Link_1723383289" MODIFIED="1174848772902">
<richcontent TYPE="NODE"><html>
  <head>
    
  </head>
  <body>
    <img src="slide-build.png" />
  </body>
</html>
</richcontent>
</node>
</node>
<node CREATED="1174841275781" ID="Freemind_Link_341540712" MODIFIED="1174841448838" POSITION="right" TEXT="Skip everything">
<icon BUILTIN="button_cancel"/>
<node CREATED="1174841283118" ID="Freemind_Link_656473777" MODIFIED="1174841462467" TEXT="Put a red X"/>
<node CREATED="1174841463266" ID="Freemind_Link_252156480" MODIFIED="1174841468552" TEXT="And the slide is disabled"/>
</node>
<node CREATED="1174848435964" ID="Freemind_Link_545870954" MODIFIED="1174848450137" POSITION="right" TEXT="Skip a slide">
<icon BUILTIN="button_ok"/>
<node CREATED="1174848452752" ID="Freemind_Link_692571033" MODIFIED="1174848514621" TEXT="You can skip a slide like the previous one, which you didn&apos;t see."/>
<node CREATED="1174848519980" ID="Freemind_Link_1102571794" MODIFIED="1174848530343">
<richcontent TYPE="NODE"><html>
  <head>
    
  </head>
  <body>
    <img src="skip-everything.png" />
  </body>
</html>
</richcontent>
</node>
</node>
<node CREATED="1174752104422" ID="Freemind_Link_846585405" MODIFIED="1174847601163" POSITION="right" TEXT="Pros">
<icon BUILTIN="button_ok"/>
<node CREATED="1174839324379" ID="Freemind_Link_1022412731" MODIFIED="1174847597779" TEXT="Advantages of mm2s5">
<node CREATED="1174839332711" ID="Freemind_Link_717364200" MODIFIED="1174839345232" TEXT="Very quick and easy"/>
<node CREATED="1174839345760" ID="Freemind_Link_1978241350" MODIFIED="1174839363717" TEXT="FreeMind has a great GUI and is very intuitive to use"/>
<node CREATED="1174839364701" ID="Freemind_Link_1996043803" MODIFIED="1174839375267" TEXT="FreeMind and S5 are actively supported"/>
<node CREATED="1174839375805" ID="Freemind_Link_803895694" MODIFIED="1174839711508" TEXT="FreeMinds, S5 and mm2s5 are all cross platform"/>
<node CREATED="1174839720517" ID="Freemind_Link_1436744254" MODIFIED="1174839733297" TEXT="FreeMind is useful for more than just presentations :-)"/>
<node CREATED="1174839670187" ID="Freemind_Link_701917635" MODIFIED="1174839684137" TEXT="You can create nice presentations templates in CSS"/>
</node>
</node>
<node CREATED="1174839411719" ID="Freemind_Link_1493526131" MODIFIED="1174847896443" POSITION="right" TEXT="Cons">
<icon BUILTIN="button_ok"/>
<node CREATED="1174839413823" ID="Freemind_Link_1517639954" MODIFIED="1174839420364" TEXT="Problems with mm2s5">
<node CREATED="1174839421091" ID="Freemind_Link_1092961195" MODIFIED="1174839437378" TEXT="Need to edit/compile/test your presentations"/>
<node CREATED="1174839438256" ID="Freemind_Link_1702747986" MODIFIED="1174839462229" TEXT="You need to remember to save in FreeMind"/>
<node CREATED="1174839462861" ID="Freemind_Link_1660574451" MODIFIED="1174839491256" TEXT="Everytime you refresh your presentation in the browser, you start on page 1"/>
<node CREATED="1174839492351" ID="Freemind_Link_794802210" MODIFIED="1174839511269" TEXT="No support for notes in the new S5 version">
<node CREATED="1174839511652" ID="Freemind_Link_1023589920" MODIFIED="1174839520732" TEXT="Hey, but that&apos;s where you can help!"/>
</node>
</node>
</node>
<node CREATED="1174839582375" ID="Freemind_Link_454371010" MODIFIED="1174839586697" POSITION="right" TEXT="Conclusions">
<node CREATED="1174839587271" ID="Freemind_Link_1043861456" MODIFIED="1174839607333" TEXT="If you stick to a simple presentations you can create something very quickly and easily"/>
<node CREATED="1174839607804" ID="Freemind_Link_1202228416" MODIFIED="1174839627642" TEXT="S5 is cross platform and you can show it anywhere"/>
<node CREATED="1174839639074" ID="Freemind_Link_1010048099" MODIFIED="1174839661292" TEXT="For longer presentations, you may find the edit/compile/test process tedious"/>
</node>
<node CREATED="1174752134072" ID="Freemind_Link_849227098" MODIFIED="1174838973294" POSITION="right" TEXT="Links">
<node CREATED="1174752136752" ID="Freemind_Link_706815722" MODIFIED="1174839811572" TEXT=" &lt;a href=&quot;http://freemind.sourceforge.net/wiki/index.php/Main_Page&quot;&gt;FreeMind&lt;/a&gt;"/>
<node CREATED="1174838973268" ID="Freemind_Link_539202117" MODIFIED="1174838977963" TEXT="S5">
<node CREATED="1174752143608" ID="Freemind_Link_1309153264" MODIFIED="1174838960582" TEXT="mm2s5 is known to work with&lt;a href=&quot;http://meyerweb.com/eric/tools/s5/&quot;&gt;S5 v1.1&lt;/a&gt;"/>
<node CREATED="1174838981291" ID="Freemind_Link_108227082" MODIFIED="1174839022692" TEXT="untested with the newer &lt;a href=&quot;http://s5project.org/&quot;&gt;S5 Project&lt;/a&gt;"/>
</node>
<node CREATED="1174752146196" ID="Freemind_Link_1896164373" MODIFIED="1174839817016" TEXT=" &lt;a href=&quot;http://code.google.com/p/mm2s5/&quot;&gt;mm2s5&lt;/a&gt;"/>
</node>
</node>
</map>
